@@ -1,9 +1,7 @@
 #![deny(warnings)]
-use sauron::{
-    html::{attributes::*, *},
-    mt_dom::patch::*,
-    node, *,
-};
+
+use crate::mt_dom::TreePath;
+use sauron::prelude::*;
 
 use test_fixtures::simple_program;
 use wasm_bindgen_test::*;
@@ -169,48 +167,41 @@ fn test_lines() {
     dom_updater.patch_dom(
         &simple_program,
         vec![
-            ChangeText::new(
-                &Text::new("0"),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 1, 0, 0, 0, 0, 0]),
-                &Text::new("1"),
-            )
-            .into(),
-            ChangeText::new(
-                &Text::new("1"),
+                &leaf::text("0"),
+                &leaf::text("1"),
+            ),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 1, 0, 0, 1, 0, 0]),
-                &Text::new("2"),
-            )
-            .into(),
-            ChangeText::new(
-                &Text::new("2"),
+                &leaf::text("1"),
+                &leaf::text("2"),
+            ),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 1, 0, 0, 2, 0, 0]),
-                &Text::new("3"),
-            )
-            .into(),
-            ChangeText::new(
-                &Text::new("3"),
+                &leaf::text("2"),
+                &leaf::text("3"),
+            ),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 1, 0, 0, 3, 0, 0]),
-                &Text::new("4"),
-            )
-            .into(),
-            ChangeText::new(
-                &Text::new("4"),
+                &leaf::text("3"),
+                &leaf::text("4"),
+            ),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 1, 0, 0, 4, 0, 0]),
-                &Text::new("5"),
-            )
-            .into(),
-            InsertNode::new(
+                &leaf::text("4"),
+                &leaf::text("5"),
+            ),
+            Patch::insert_node(
                 Some(&"div"),
                 TreePath::new(vec![0, 1, 0, 0, 0]),
                 &inserted,
-            )
-            .into(),
-            ChangeText::new(
-                &Text::new("line: 0, column: 0"),
+            ),
+            Patch::replace_leaf(
                 TreePath::new(vec![0, 1, 0, 1, 0]),
-                &Text::new("line: 1, column: 0"),
-            )
-            .into(),
+                &leaf::text("line: 0, column: 0"),
+                &leaf::text("line: 1, column: 0"),
+            ),
         ],
     );
 }
