@@ -4,13 +4,13 @@
 //! use for doing component tests
 //!
 use log::*;
-use sauron::{html::div, Cmd, Component, Node, Program};
+use sauron::{html::div, Application, Cmd, Node, Program};
 
 /// This is a simple component for the puprpose of testing
 #[derive(Copy, Clone, Debug)]
 pub struct SimpleComponent;
 
-impl Component<()> for SimpleComponent {
+impl Application<()> for SimpleComponent {
     fn update(&mut self, _msg: ()) -> Cmd<Self, ()> {
         trace!("updating in SimpleComponent");
         Cmd::none()
